package com.example.mlearningremesla

import android.content.Intent
import android.graphics.Color
import android.graphics.Typeface
import android.os.Bundle
import android.os.CountDownTimer
import android.os.SystemClock
import android.view.View
import android.widget.TextView
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContextCompat
import com.example.mlearningremesla.databinding.ActivityOstrytestBinding
import com.google.firebase.auth.FirebaseAuth
import kotlinx.android.synthetic.main.activity_ostrytest.*
import kotlinx.android.synthetic.main.activity_vysledek.*
import java.util.*
import kotlin.collections.ArrayList

class OstryTestActivity : AppCompatActivity(), View.OnClickListener{
    private lateinit var binding: ActivityOstrytestBinding

    private var mCurrentPosition:Int = 1
    private var mQuestionsList: ArrayList<Otazky>? = null
    private var mSelectedOptionPosition : Int = 0
    private var mCorrectAnswers: Int = 0


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityOstrytestBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)

        mQuestionsList = Constants.getQuestions()

        setQuestion()

        //tvTimer.base = SystemClock.elapsedRealtime() + 100000
        //tvTimer.start()

        initData()
        moznostJedna.setOnClickListener(this)
        moznostDva.setOnClickListener(this)
        moznostTri.setOnClickListener(this)
        moznostCtyri.setOnClickListener(this)
        btnPotvrdit.setOnClickListener(this)

    }

    private fun setQuestion(){
        val otazka = mQuestionsList!![mCurrentPosition-1]
        zakladniMoznostView()

        if (mCurrentPosition == mQuestionsList!!.size){
            btnPotvrdit.text = "KONEC"
        }else{
            btnPotvrdit.text = "POTVRĎIT"
        }

        progressBar.progress = mCurrentPosition
        progressHodnota.text ="$mCurrentPosition" + "/" + progressBar.max

        nadpisOtazka.text = otazka!!.question
        moznostJedna.text = otazka.moznostjedna
        moznostDva.text = otazka.moznostdva
        moznostTri.text = otazka.moznosttri
        moznostCtyri.text = otazka.moznostctyri
    }

    private fun zakladniMoznostView(){
        val options = ArrayList<TextView>()
        options.add(0, moznostJedna)
        options.add(1, moznostDva)
        options.add(2, moznostTri)
        options.add(3, moznostCtyri)

        for (option in options){
            option.setTextColor(Color.parseColor("#7A8089"))
            option.typeface = Typeface.DEFAULT
            option.background = ContextCompat.getDrawable(this, R.drawable.default_option_border_bg)
        }

    }

    override fun onClick(v: View?) {
        when(v?.id){
            R.id.moznostJedna ->{
                vybranaMoznostView(moznostJedna,1)
            }
            R.id.moznostDva ->{
                vybranaMoznostView(moznostDva,2)
            }
            R.id.moznostTri ->{
                vybranaMoznostView(moznostTri,3)
            }
            R.id.moznostCtyri ->{
                vybranaMoznostView(moznostCtyri,4)
            }
            R.id.btnPotvrdit ->{
                if (mSelectedOptionPosition == 0){
                    mCurrentPosition++
                    when{
                        mCurrentPosition <= mQuestionsList!!.size ->{
                            setQuestion()
                        }else ->{
                            val intent = Intent(this, VysledekActivity::class.java)
                            intent.putExtra(Constants.CORRECT_ANSWERS, mCorrectAnswers)
                            intent.putExtra(Constants.TOTAL_QUESTIONS, mQuestionsList!!.size)
                            startActivity(intent)
                        }
                    }
                }else{
                    val question = mQuestionsList?.get(mCurrentPosition -1)
                    if (question!!.spravnamoznost != mSelectedOptionPosition){
                        odpovedView(mSelectedOptionPosition,R.drawable.wrong_option_border_bg)
                    }else{
                        mCorrectAnswers++
                    }
                    odpovedView(question.spravnamoznost,R.drawable.correct_option_border_bg)
                    if(mCurrentPosition == mQuestionsList!!.size){
                        btnPotvrdit.text = "KONEC"
                    }else{
                        btnPotvrdit.text = "DALŠÍ OTÁZKA"
                    }
                    mSelectedOptionPosition = 0
                }


            }
        }
    }
    private fun odpovedView(odpoved: Int, drawableview: Int){
        when(odpoved){
            1 ->{
                moznostJedna.background = ContextCompat.getDrawable(this,drawableview)
            }
            2 ->{
                moznostDva.background = ContextCompat.getDrawable(this,drawableview)
            }
            3 ->{
                moznostTri.background = ContextCompat.getDrawable(this,drawableview)
            }
            4 ->{
                moznostCtyri.background = ContextCompat.getDrawable(this,drawableview)
            }
        }

    }


    private fun vybranaMoznostView(tv: TextView, selectedOptionNum :Int){
        zakladniMoznostView()
        mSelectedOptionPosition = selectedOptionNum

        tv.setTextColor(Color.parseColor("#363A43"))
        tv.setTypeface(tv.typeface, Typeface.BOLD)
        tv.background = ContextCompat.getDrawable(this, R.drawable.selected_option_border_bg)
    }
    private fun initData(){
        clickListener();
    }

    private fun clickListener(){
        binding.btnZpetDoMenu.setOnClickListener{
            startActivity(Intent(this,KovarstviActivity::class.java))
            finish()
        }
    }

}